X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/7c74e7fe1de14f32dcd6f3c9cdd727de540bbd0e..61b50a43aaaf29fe9c2f848958adafc496439123:/include/wx/mac/window.h

diff --git a/include/wx/mac/window.h b/include/wx/mac/window.h
index 3eac7270ce..9c449c2413 100644
--- a/include/wx/mac/window.h
+++ b/include/wx/mac/window.h
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        window.h
 // Purpose:     wxWindow class
 // Author:      AUTHOR
 // Modified by:
 // Created:     ??/??/98
@@ -34,9 +34,9 @@ enum
     wxKEY_CTRL  = 2
 };
 
-class WXDLLEXPORT wxWindow: public wxWindowBase
+class WXDLLEXPORT wxWindowMac: public wxWindowBase
 {
-  DECLARE_DYNAMIC_CLASS(wxWindow);
+  DECLARE_DYNAMIC_CLASS(wxWindowMac);
 
   friend class wxDC;
   friend class wxPaintDC;
@@ -47,13 +47,14 @@ public:
 			SInt16								m_macWindowBackgroundTheme ;
 			WindowRef							m_macWindow ;
 			ControlHandle					m_macRootControl ;
-			wxWindow*							m_macFocus ;
+			wxWindowMac*							m_macFocus ;
+			bool                                m_macHasReceivedFirstActivate ;
 	} MacWindowData ;
 	
 	
-    wxWindow() { Init(); }
+    wxWindowMac() { Init(); }
 
-    wxWindow(wxWindow *parent,
+    wxWindowMac(wxWindowMac *parent,
              wxWindowID id,
              const wxPoint& pos = wxDefaultPosition,
              const wxSize& size = wxDefaultSize,
@@ -64,9 +65,9 @@ public:
         Create(parent, id, pos, size, style, name);
     }
 
-    virtual ~wxWindow();
+    virtual ~wxWindowMac();
 
-    bool Create(wxWindow *parent,
+    bool Create(wxWindowMac *parent,
                 wxWindowID id,
                 const wxPoint& pos = wxDefaultPosition,
                 const wxSize& size = wxDefaultSize,
@@ -86,8 +87,6 @@ public:
 
     virtual void SetFocus();
 
-    virtual bool Reparent( wxWindow *newParent );
-
     virtual void WarpPointer(int x, int y);
     virtual void CaptureMouse();
     virtual void ReleaseMouse();
@@ -135,7 +134,7 @@ public:
 
     // event handlers
         // Handle a control command
-    virtual void OnCommand(wxWindow& win, wxCommandEvent& event);
+    virtual void OnCommand(wxWindowMac& win, wxCommandEvent& event);
 
         // Override to define new behaviour for default action (e.g. double
         // clicking on a listbox)
@@ -155,15 +154,16 @@ public:
 
     // Native resource loading (implemented in src/msw/nativdlg.cpp)
     // FIXME: should they really be all virtual?
-    wxWindow* GetWindowChild1(wxWindowID id);
-    wxWindow* GetWindowChild(wxWindowID id);
+    wxWindowMac* GetWindowChild1(wxWindowID id);
+    wxWindowMac* GetWindowChild(wxWindowID id);
 
     // implementation from now on
     // --------------------------
 
 	void MacClientToRootWindow( int *x , int *y ) const ;
 	void MacRootWindowToClient( int *x , int *y ) const ;
-
+	
+	virtual wxString MacGetToolTipString( wxPoint &where ) ;
 
     // simple accessors
     // ----------------
@@ -178,9 +178,12 @@ public:
 
     // event handlers
     // --------------
+	void OnSetFocus(wxFocusEvent& event) ;
     void OnEraseBackground(wxEraseEvent& event);
     void OnIdle(wxIdleEvent& event);
     void MacOnScroll(wxScrollEvent&event ) ;
+    
+    bool AcceptsFocus() const ;
 
 public:
     // For implementation purposes - sometimes decorations make the client area
@@ -191,8 +194,8 @@ public:
     // a toolbar that it manages itself).
     virtual void AdjustForParentClientOrigin(int& x, int& y, int sizeFlags);
 
-    wxWindow *FindItem(long id) const;
-    wxWindow *FindItemByHWND(WXHWND hWnd, bool controlOnly = FALSE) const;
+    wxWindowMac *FindItem(long id) const;
+    wxWindowMac *FindItemByHWND(WXHWND hWnd, bool controlOnly = FALSE) const;
 
     // Make a Windows extended style from the given wxWindows window style
     static WXDWORD MakeExtendedStyle(long style,
@@ -219,9 +222,13 @@ public:
 
     // Responds to colour changes: passes event on to children.
     void OnSysColourChanged(wxSysColourChangedEvent& event);
-
 public :
-	static bool							MacGetWindowFromPoint( const wxPoint &point , wxWindow** outWin ) ;
+	virtual void						MacCreateRealWindow( const wxString& title,
+           const wxPoint& pos,
+           const wxSize& size,
+           long style,
+           const wxString& name ) ;
+	static bool							MacGetWindowFromPoint( const wxPoint &point , wxWindowMac** outWin ) ;
 	virtual void						MacActivate( EventRecord *ev , bool inIsActivating ) ;
 	virtual void						MacUpdate( EventRecord *ev ) ;
 	virtual void						MacUpdateImmediately() ;
@@ -235,31 +242,45 @@ public :
 	virtual void						MacFireMouseEvent( EventRecord *ev ) ;
 	virtual bool						MacDispatchMouseEvent(wxMouseEvent& event ) ;
 	virtual void						MacEraseBackground( Rect *rect ) ;
-	WindowRef								GetMacRootWindow() const  ;
+	virtual void 						MacPaintBorders() ;
+	// obsolete : only for link compatibility
+	virtual void 						MacPaint( wxPaintEvent &event ) ;
+	WindowRef							GetMacRootWindow() const  ;
 
-	virtual ControlHandle 	MacGetContainerForEmbedding() ;
-	virtual void 						MacSuperChangedPosition() ;
+	virtual ControlHandle 				MacGetContainerForEmbedding() ;
+	
+	virtual long						MacGetLeftBorderSize() const ;
+	virtual long						MacGetRightBorderSize() const ;
+	virtual long						MacGetTopBorderSize() const ;
+	virtual long						MacGetBottomBorderSize() const ;
 
+	static long							MacRemoveBordersFromStyle( long style ) ;
+	virtual void 						MacSuperChangedPosition() ;
+	virtual void						MacSuperShown( bool show ) ;
+	bool								MacIsReallyShown() const ;
+/*
 	bool										MacSetupFocusPort() ;
 	bool										MacSetupDrawingPort() ;
 	bool										MacSetupFocusClientPort() ;
 	bool										MacSetupDrawingClientPort() ;
-	
-	virtual bool						MacSetPortFocusParams( const Point & localOrigin, const Rect & clipRect, WindowRef window , wxWindow* rootwin )  ;
-	virtual bool						MacSetPortDrawingParams( const Point & localOrigin, const Rect & clipRect, WindowRef window , wxWindow* rootwin )  ;
+*/	
+	virtual bool						MacSetPortFocusParams( const Point & localOrigin, const Rect & clipRect, WindowRef window , wxWindowMac* rootwin )  ;
+	virtual bool						MacSetPortDrawingParams( const Point & localOrigin, const Rect & clipRect, WindowRef window , wxWindowMac* rootwin )  ;
 
-	virtual void						MacGetPortParams(Point* localOrigin, Rect* clipRect, WindowRef *window , wxWindow** rootwin ) ;
-	virtual void						MacGetPortClientParams(Point* localOrigin, Rect* clipRect, WindowRef *window  , wxWindow** rootwin) ;
+	virtual void						MacGetPortParams(Point* localOrigin, Rect* clipRect, WindowRef *window , wxWindowMac** rootwin ) ;
+	virtual void						MacGetPortClientParams(Point* localOrigin, Rect* clipRect, WindowRef *window  , wxWindowMac** rootwin) ;
+	virtual void						MacDoGetPortClientParams(Point* localOrigin, Rect* clipRect, WindowRef *window  , wxWindowMac** rootwin) ;
 	MacWindowData*						MacGetWindowData() { return m_macWindowData ; }
 	static WindowRef					MacGetWindowInUpdate() { return s_macWindowInUpdate ; }
 	bool								MacIsWindowScrollbar( const wxScrollBar* sb ) { return (m_hScrollBar == sb || m_vScrollBar == sb) ; }
-	static wxWindow*					s_lastMouseWindow ;
+	static wxWindowMac*					s_lastMouseWindow ;
 private:
-	virtual bool						MacGetWindowFromPointSub( const wxPoint &point , wxWindow** outWin ) ;
+	virtual bool						MacGetWindowFromPointSub( const wxPoint &point , wxWindowMac** outWin ) ;
 protected:
-
 	MacWindowData*				m_macWindowData ;
 	static WindowRef			s_macWindowInUpdate ;
+	RgnHandle					m_macUpdateRgn ;
+	bool						m_macEraseOnRedraw ;
 
 	int 									m_x ;
 	int 									m_y ;	
@@ -297,10 +318,6 @@ protected:
                            int sizeFlags = wxSIZE_AUTO);
     virtual void DoSetClientSize(int width, int height);
 
-    // get the size which best suits the window: e.g., for a static text it
-    // will be the width and height of the text
-    virtual wxSize DoGetBestSize();
-
     // move the window to the specified location and resize it: this is called
     // from both DoSetSize() and DoSetClientSize() and would usually just call
     // ::MoveWindow() except for composite controls which will want to arrange
@@ -315,20 +332,21 @@ private:
     // common part of all ctors
     void Init();
 
-    DECLARE_NO_COPY_CLASS(wxWindow);
+    DECLARE_NO_COPY_CLASS(wxWindowMac)
     DECLARE_EVENT_TABLE()
 };
 
 // associate mac windows with wx counterparts
 
-wxWindow* wxFindWinFromMacWindow( WindowRef inWindow ) ;
-void wxAssociateWinWithMacWindow(WindowRef inWindow, wxWindow *win) ;
-void wxRemoveMacWindowAssociation(wxWindow *win) ;
+wxWindowMac* wxFindWinFromMacWindow( WindowRef inWindow ) ;
+void wxAssociateWinWithMacWindow(WindowRef inWindow, wxWindowMac *win) ;
+void wxRemoveMacWindowAssociation(wxWindowMac *win) ;
 
+/*
 class wxMacFocusHelper
 {
 public :
-	wxMacFocusHelper( wxWindow * theWindow ) ;
+	wxMacFocusHelper( wxWindowMac * theWindow ) ;
 	~wxMacFocusHelper() ;
 	bool Ok() { return m_ok ; }
 
@@ -337,11 +355,12 @@ private :
 	GrafPtr		m_currentPort ;
 	bool			m_ok ;
 } ;
+*/
 
 class wxMacDrawingHelper
 {
 public :
-	wxMacDrawingHelper( wxWindow * theWindow ) ;
+	wxMacDrawingHelper( wxWindowMac * theWindow ) ;
 	~wxMacDrawingHelper() ;
 	bool Ok() { return m_ok ; }
 
@@ -351,11 +370,11 @@ private :
 	PenState 	m_savedPenState ;
 	bool			m_ok ;
 } ;
-
+/*
 class wxMacFocusClientHelper
 {
 public :
-	wxMacFocusClientHelper( wxWindow * theWindow ) ;
+	wxMacFocusClientHelper( wxWindowMac * theWindow ) ;
 	~wxMacFocusClientHelper() ;
 	bool Ok() { return m_ok ; }
 
@@ -364,11 +383,11 @@ private :
 	GrafPtr		m_currentPort ;
 	bool			m_ok ;
 } ;
-
+*/
 class wxMacDrawingClientHelper
 {
 public :
-	wxMacDrawingClientHelper( wxWindow * theWindow ) ;
+	wxMacDrawingClientHelper( wxWindowMac * theWindow ) ;
 	~wxMacDrawingClientHelper() ;
 	bool Ok() { return m_ok ; }
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        window.h
-// Purpose:     wxWindow class
+// Purpose:     wxWindowMac class
 // Author:      AUTHOR
 // Modified by: